AeroCacheException class
Base exception class for all AeroCache operations
- Implemented types
- Implementers
Constructors
- AeroCacheException(String message, [Object? originalException])
-
Create a new AeroCacheException
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error message
final
- originalException → Object?
-
Original exception that caused this error
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited